/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.camera;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.component.model.InputPort;
import org.fortiss.af3.platform.raspberry.generator.extension.library.PiHALLibraryGeneratorExtensionBase;
import org.fortiss.af3.platform.raspberry.generator.framework.IReadableGeneratorExtension;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;

/**
 * Base class for all executables of the camera input sensors.
 * 
 * @author hoelzl
 */
abstract class CameraGeneratorExtensionBase<T extends EObject> extends
		PiHALLibraryGeneratorExtensionBase<T> implements IReadableGeneratorExtension {
	/** Constructor. */
	public CameraGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonVariableDeclarationCode() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonAuxiliaryFunctions() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonInitializationCode() {
		if(modelElement.eContainer() instanceof RaspberryPi) {
			RaspberryPi raspi = (RaspberryPi)modelElement.eContainer();
			StringBuilder sb = new StringBuilder();
			sb.append("camera_client_initialize(\"");
			sb.append(raspi.getCameraServerAddress()).append("\", \"");
			sb.append(raspi.getCameraServerPort()).append("\");\n\n");
			return sb.toString();
		}
		return "FIXME(\"eContainer() of model element " + modelElement + " is not a RasPi\"";
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonTerminationCode() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonIdentifier() {
		// use header file as singleton identifier
		return getHeaderFileName();
	}

	/** {@inheritDoc} */
	@Override
	public final String getHeaderFileName() {
		return "camera_client.h";
	}

	/** {@inheritDoc} */
	@Override
	public final String getReadCode(InputPort logicalSignal, String targetVariable) {
		return targetVariable + " = " + getCameraValueFunction() + ";\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getNoValReadCode(InputPort logicalSignal) {
		return null;
	}

	/**
	 * Returns the function from camera_client.h, which is used by the
	 * {@link #getReadCode(InputPort, String)} method to generate the code.
	 */
	protected abstract String getCameraValueFunction();
}
