/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.util;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createConnectorLayout;

import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.ConsoleOutput;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.RaspberryPiModelFactory;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.ActuatorDigits;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.BrickFactory;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonBActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonGActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonRActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LaserRangeSensor;
import org.fortiss.af3.platform.raspberry.model.brick.UltraSonicSensor;
import org.fortiss.af3.platform.raspberry.model.camera.CameraConnected;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraFactory;
import org.fortiss.af3.platform.raspberry.model.camera.CameraLastUpdate;
import org.fortiss.af3.platform.raspberry.model.camera.CameraYawAngle;
import org.fortiss.af3.platform.raspberry.model.controlcenter.ControlCenterDownstreamInput;
import org.fortiss.af3.platform.raspberry.model.controlcenter.ControlCenterUpstreamOutput;
import org.fortiss.af3.platform.raspberry.model.controlcenter.ControlcenterFactory;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button1;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button3;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button4;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL2;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR2;
import org.fortiss.af3.platform.raspberry.model.gamepad.GamepadFactory;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlInput;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlOutput;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorcontrolFactory;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonA;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonB;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonHome;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL3;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR3;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonSelect;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonStart;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonX;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonY;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadDown;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadLeft;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadRight;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadUp;
import org.fortiss.af3.platform.raspberry.model.rumblepad.L2_Position;
import org.fortiss.af3.platform.raspberry.model.rumblepad.R2_Position;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeStrong;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeWeak;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumblepadFactory;
import org.fortiss.af3.platform.raspberry.model.rumblepad.SimpleRumbleFeature;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VFollowerInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VFollowerOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VFusePlatoonInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VFusePlatoonOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VHandshakeInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VHandshakeOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLeaderHeartbeatInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLeaderHeartbeatOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLeaderUIDOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLeavePlatoonInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLeavePlatoonOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VLocalUIDOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VNewLeaderInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VNewLeaderOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VPlatoonInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VPlatoonOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VPrecedingUIDOuput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VSplitInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VSplitOutput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2vFactory;
import org.fortiss.tooling.base.utils.LayoutModelElementFactory;

/** Model Element for {@link RaspberryPi} and related model elements. */
public class RaspberryModelElementFactory {
	/** Creates a {@link RaspberryPi}. */
	public static RaspberryPi createRaspberryPi() {
		final RaspberryPi pi = RaspberryPiModelFactory.eINSTANCE.createRaspberryPi();
		LayoutModelElementFactory.createNodeElementLayout(pi);
		pi.setName("RaspberryPI");
		pi.setCanCoordinationID(255);
		pi.setCycleTime(100);
		pi.setIpAddress("192.168.21.241");
		pi.setCoordinatorUnit(false);
		return pi;
	}

	/** Creates a {@link CanBus}. */
	public static CanBus createCanBus() {
		final CanBus bus = RaspberryPiModelFactory.eINSTANCE.createCanBus();
		LayoutModelElementFactory.createNodeElementLayout(bus);
		bus.setName("CanBus");
		return bus;
	}

	/** Creates a {@link CanConnector}. */
	public static CanConnector createCanConnector() {
		CanConnector canConnector = RaspberryPiModelFactory.eINSTANCE.createCanConnector();
		canConnector.setName("CanConnector");
		createConnectorLayout(canConnector);
		return canConnector;
	}

	/** Creates a {@link ActuatorPWM}. */
	public static ActuatorPWM createActuatorPWM() {
		ActuatorPWM connector = RaspberryPiModelFactory.eINSTANCE.createActuatorPWM();
		connector.setName("PWM");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link ConsoleOutput}. */
	public static ConsoleOutput createConsoleOutput() {
		ConsoleOutput connector = RaspberryPiModelFactory.eINSTANCE.createConsoleOutput();
		connector.setName("Console");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link Button1}. */
	public static Button1 createButton1() {
		Button1 button = GamepadFactory.eINSTANCE.createButton1();
		button.setName("Button1_Triangle");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button2}. */
	public static Button2 createButton2() {
		Button2 button = GamepadFactory.eINSTANCE.createButton2();
		button.setName("Button2_Circle");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button3}. */
	public static Button3 createButton3() {
		Button3 button = GamepadFactory.eINSTANCE.createButton3();
		button.setName("Button3_X");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button4}. */
	public static Button4 createButton4() {
		Button4 button = GamepadFactory.eINSTANCE.createButton4();
		button.setName("Button4_Square");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonR1}. */
	public static ButtonR1 createButtonR1() {
		ButtonR1 button = GamepadFactory.eINSTANCE.createButtonR1();
		button.setName("ButtonR1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonL1}. */
	public static ButtonL1 createButtonL1() {
		ButtonL1 button = GamepadFactory.eINSTANCE.createButtonL1();
		button.setName("ButtonL1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonR2}. */
	public static ButtonR2 createButtonR2() {
		ButtonR2 button = GamepadFactory.eINSTANCE.createButtonR2();
		button.setName("ButtonR2");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonL2}. */
	public static ButtonL2 createButtonL2() {
		ButtonL2 button = GamepadFactory.eINSTANCE.createButtonL2();
		button.setName("ButtonL2");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Left_StickX_Position}. */
	public static Left_StickX_Position createLeftStickX() {
		Left_StickX_Position button = GamepadFactory.eINSTANCE.createLeft_StickX_Position();
		button.setName("Left_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Left_StickY_Position}. */
	public static Left_StickY_Position createLeftStickY() {
		Left_StickY_Position button = GamepadFactory.eINSTANCE.createLeft_StickY_Position();
		button.setName("Left_StickY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Right_StickX_Position}. */
	public static Right_StickX_Position createRightStickX() {
		Right_StickX_Position button = GamepadFactory.eINSTANCE.createRight_StickX_Position();
		button.setName("Right_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Right_StickY_Position}. */
	public static Right_StickY_Position createRightStickY() {
		Right_StickY_Position button = GamepadFactory.eINSTANCE.createRight_StickY_Position();
		button.setName("Right_StickY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link UltraSonicSensor}. */
	public static UltraSonicSensor createUltraSonicSensor() {
		UltraSonicSensor sensor = BrickFactory.eINSTANCE.createUltraSonicSensor();
		sensor.setName("UltraSonicSensor");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link LaserRangeSensor}. */
	public static LaserRangeSensor createLaserRangeSensor() {
		LaserRangeSensor sensor = BrickFactory.eINSTANCE.createLaserRangeSensor();
		sensor.setName("LaserRangeSensor");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AccelerationXSensor}. */
	public static AccelerationXSensor createAccelerationXSensor() {
		AccelerationXSensor sensor = BrickFactory.eINSTANCE.createAccelerationXSensor();
		sensor.setName("AccelerationSensorX");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AccelerationYSensor}. */
	public static AccelerationYSensor createAccelerationYSensor() {
		AccelerationYSensor sensor = BrickFactory.eINSTANCE.createAccelerationYSensor();
		sensor.setName("AccelerationSensorY");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AccelerationZSensor}. */
	public static AccelerationZSensor createAccelerationZSensor() {
		AccelerationZSensor sensor = BrickFactory.eINSTANCE.createAccelerationZSensor();
		sensor.setName("AccelerationSensorZ");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AngularVelocityXSensor}. */
	public static AngularVelocityXSensor createAngularVelocityXSensor() {
		AngularVelocityXSensor sensor = BrickFactory.eINSTANCE.createAngularVelocityXSensor();
		sensor.setName("AngularVelocitySensorX");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AngularVelocityYSensor}. */
	public static AngularVelocityYSensor createAngularVelocityYSensor() {
		AngularVelocityYSensor sensor = BrickFactory.eINSTANCE.createAngularVelocityYSensor();
		sensor.setName("AngularVelocitySensorY");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates a {@link AngularVelocityZSensor}. */
	public static AngularVelocityZSensor createAngularVelocityZSensor() {
		AngularVelocityZSensor sensor = BrickFactory.eINSTANCE.createAngularVelocityZSensor();
		sensor.setName("AngularVelocitySensorZ");
		createConnectorLayout(sensor);
		return sensor;
	}

	/** Creates an {@link ActuatorDigits}. */
	public static ActuatorDigits createActuatorDigits() {
		ActuatorDigits ad = BrickFactory.eINSTANCE.createActuatorDigits();
		ad.setName("SegmentDigits");
		ad.setUniqueBrickletID("");
		ad.setShowHexValue(false);
		createConnectorLayout(ad);
		return ad;
	}

	/** Creates an {@link LEDButtonRActuator} for controlling red color. */
	public static LEDButtonRActuator createLEDButtonRActuator() {
		LEDButtonRActuator led = BrickFactory.eINSTANCE.createLEDButtonRActuator();
		led.setName("LED_Button_Red");
		led.setUniqueBrickletID("");
		createConnectorLayout(led);
		return led;
	}

	/** Creates an {@link LEDButtonRActuator} for controlling green color. */
	public static LEDButtonGActuator createLEDButtonGActuator() {
		LEDButtonGActuator led = BrickFactory.eINSTANCE.createLEDButtonGActuator();
		led.setName("LED_Button_Green");
		led.setUniqueBrickletID("");
		createConnectorLayout(led);
		return led;
	}

	/** Creates an {@link LEDButtonRActuator} for controlling blue color. */
	public static LEDButtonBActuator createLEDButtonBActuator() {
		LEDButtonBActuator led = BrickFactory.eINSTANCE.createLEDButtonBActuator();
		led.setName("LED_Button_Blue");
		led.setUniqueBrickletID("");
		createConnectorLayout(led);
		return led;
	}

	/** Creates a {@link ButtonA}. */
	public static ButtonA createRumbleButtonA() {
		ButtonA button = RumblepadFactory.eINSTANCE.createButtonA();
		button.setName("ButtonA");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonA}. */
	public static ButtonB createRumbleButtonB() {
		ButtonB button = RumblepadFactory.eINSTANCE.createButtonB();
		button.setName("ButtonB");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonA}. */
	public static ButtonX createRumbleButtonX() {
		ButtonX button = RumblepadFactory.eINSTANCE.createButtonX();
		button.setName("ButtonX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonY}. */
	public static ButtonY createRumbleButtonY() {
		ButtonY button = RumblepadFactory.eINSTANCE.createButtonY();
		button.setName("ButtonY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonStart}. */
	public static ButtonStart createRumbleButtonStart() {
		ButtonStart button = RumblepadFactory.eINSTANCE.createButtonStart();
		button.setName("ButtonStart");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonSelect}. */
	public static ButtonSelect createRumbleButtonSelect() {
		ButtonSelect button = RumblepadFactory.eINSTANCE.createButtonSelect();
		button.setName("ButtonSelect");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonHome}. */
	public static ButtonHome createRumbleButtonHome() {
		ButtonHome button = RumblepadFactory.eINSTANCE.createButtonHome();
		button.setName("ButtonHome");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL1}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL1
			createRumbleButtonL1() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL1 button =
				RumblepadFactory.eINSTANCE.createButtonL1();
		button.setName("ButtonL1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonL3}. */
	public static ButtonL3 createRumbleButtonL3() {
		ButtonL3 button = RumblepadFactory.eINSTANCE.createButtonL3();
		button.setName("ButtonL3");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR1}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR1
			createRumbleButtonR1() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR1 button =
				RumblepadFactory.eINSTANCE.createButtonR1();
		button.setName("ButtonR1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonR3}. */
	public static ButtonR3 createRumbleButtonR3() {
		ButtonR3 button = RumblepadFactory.eINSTANCE.createButtonR3();
		button.setName("ButtonR3");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link DPadUp}. */
	public static DPadUp createRumbleDPadUp() {
		DPadUp button = RumblepadFactory.eINSTANCE.createDPadUp();
		button.setName("DPadUp");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link DPadDown}. */
	public static DPadDown createRumbleDPadDown() {
		DPadDown button = RumblepadFactory.eINSTANCE.createDPadDown();
		button.setName("DPadDown");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link DPadLeft}. */
	public static DPadLeft createRumbleDPadLeft() {
		DPadLeft button = RumblepadFactory.eINSTANCE.createDPadLeft();
		button.setName("DPadLeft");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link DPadRight}. */
	public static DPadRight createRumbleDPadRight() {
		DPadRight button = RumblepadFactory.eINSTANCE.createDPadRight();
		button.setName("DPadRight");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickX_Position}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickX_Position
			createRumbleLeftStickX() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickX_Position button =
				RumblepadFactory.eINSTANCE.createLeft_StickX_Position();
		button.setName("Left_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickY_Position}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickY_Position
			createRumbleLeftStickY() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickY_Position button =
				RumblepadFactory.eINSTANCE.createLeft_StickY_Position();
		button.setName("Left_StickY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickX_Position}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickX_Position
			createRumbleRightStickX() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickX_Position button =
				RumblepadFactory.eINSTANCE.createRight_StickX_Position();
		button.setName("Right_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickY_Position}. */
	public static org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickY_Position
			createRumbleRightStickY() {
		org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickY_Position button =
				RumblepadFactory.eINSTANCE.createRight_StickY_Position();
		button.setName("Right_StickY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link L2_Position}. */
	public static L2_Position createRumbleL2Position() {
		L2_Position button = RumblepadFactory.eINSTANCE.createL2_Position();
		button.setName("L2Position");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link R2_Position}. */
	public static R2_Position createRumbleR2Position() {
		R2_Position button = RumblepadFactory.eINSTANCE.createR2_Position();
		button.setName("R2Position");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link SimpleRumbleFeature}. */
	public static SimpleRumbleFeature createRumbleSimpleRumbleFeaturePosition() {
		SimpleRumbleFeature rumble = RumblepadFactory.eINSTANCE.createSimpleRumbleFeature();
		rumble.setName("SimpleRumbleFeature");
		createConnectorLayout(rumble);
		return rumble;
	}

	/** Creates a {@link RumbleMagnitudeStrong}. */
	public static RumbleMagnitudeStrong createRumbleMagnitudeStrong() {
		RumbleMagnitudeStrong rumble = RumblepadFactory.eINSTANCE.createRumbleMagnitudeStrong();
		rumble.setName("RumbleMagnitudeStrong");
		createConnectorLayout(rumble);
		return rumble;
	}

	/** Creates a {@link RumbleMagnitudeWeak}. */
	public static RumbleMagnitudeWeak createRumbleMagnitudeWeak() {
		RumbleMagnitudeWeak rumble = RumblepadFactory.eINSTANCE.createRumbleMagnitudeWeak();
		rumble.setName("RumbleMagnitudeWeak");
		createConnectorLayout(rumble);
		return rumble;
	}

	/** Creates a {@link MotorControlInput}. */
	public static MotorControlInput createMotorControlInput() {
		MotorControlInput mci = MotorcontrolFactory.eINSTANCE.createMotorControlInput();
		mci.setName("MotorControlInput");
		createConnectorLayout(mci);
		return mci;
	}

	/** Creates a {@link MotorControlOutput}. */
	public static MotorControlOutput createMotorControlOutput() {
		MotorControlOutput mco = MotorcontrolFactory.eINSTANCE.createMotorControlOutput();
		mco.setName("MotorControlOutput");
		createConnectorLayout(mco);
		return mco;
	}

	/** Creates a {@link CameraConnected}. */
	public static CameraConnected createCameraConnected() {
		CameraConnected cc = CameraFactory.eINSTANCE.createCameraConnected();
		cc.setName("CameraConnected");
		createConnectorLayout(cc);
		return cc;
	}

	/** Creates a {@link CameraLastUpdate}. */
	public static CameraLastUpdate createCameraLastUpdate() {
		CameraLastUpdate clu = CameraFactory.eINSTANCE.createCameraLastUpdate();
		clu.setName("CameraLastUpdate");
		createConnectorLayout(clu);
		return clu;
	}

	/** Creates a {@link CameraDistanceLeft}. */
	public static CameraDistanceLeft createCameraDistanceLeft() {
		CameraDistanceLeft cdl = CameraFactory.eINSTANCE.createCameraDistanceLeft();
		cdl.setName("CameraDistanceLeft");
		createConnectorLayout(cdl);
		return cdl;
	}

	/** Creates a {@link CameraDistanceRight}. */
	public static CameraDistanceRight createCameraDistanceRight() {
		CameraDistanceRight cdr = CameraFactory.eINSTANCE.createCameraDistanceRight();
		cdr.setName("CameraDistanceRight");
		createConnectorLayout(cdr);
		return cdr;
	}

	/** Creates a {@link CameraDetectionStateLeft}. */
	public static CameraDetectionStateLeft createCameraDetectionStateLeft() {
		CameraDetectionStateLeft cdsl = CameraFactory.eINSTANCE.createCameraDetectionStateLeft();
		cdsl.setName("CameraDetectionStateLeft");
		createConnectorLayout(cdsl);
		return cdsl;
	}

	/** Creates a {@link CameraDetectionStateRight}. */
	public static CameraDetectionStateRight createCameraDetectionStateRight() {
		CameraDetectionStateRight cdsr = CameraFactory.eINSTANCE.createCameraDetectionStateRight();
		cdsr.setName("CameraDetectionStateRight");
		createConnectorLayout(cdsr);
		return cdsr;
	}

	/** Creates a {@link CameraYawAngle}. */
	public static CameraYawAngle createCameraYawAngle() {
		CameraYawAngle cya = CameraFactory.eINSTANCE.createCameraYawAngle();
		cya.setName("CameraYawAngle");
		createConnectorLayout(cya);
		return cya;
	}

	/** Creates a {@link ControlCenterDownstreamInput}. */
	public static ControlCenterDownstreamInput createControlCenterDownstreamInput() {
		ControlCenterDownstreamInput cci =
				ControlcenterFactory.eINSTANCE.createControlCenterDownstreamInput();
		cci.setName("ControlCenterInput");
		createConnectorLayout(cci);
		return cci;
	}

	/** Creates a {@link ControlCenterUpstreamOutput}. */
	public static ControlCenterUpstreamOutput createControlCenterUpstreamOutput() {
		ControlCenterUpstreamOutput cco =
				ControlcenterFactory.eINSTANCE.createControlCenterUpstreamOutput();
		cco.setName("ControlCenterOutput");
		createConnectorLayout(cco);
		return cco;
	}

	/** Creates a {@link V2VPlatoonInput} */
	public static V2VPlatoonInput createV2vPlatoonInput() {
		V2VPlatoonInput input = V2vFactory.eINSTANCE.createV2VPlatoonInput();
		input.setName("V2V Platoon Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VPlatoonOutput} */
	public static V2VPlatoonOutput createV2vPlatoonOutput() {
		V2VPlatoonOutput input = V2vFactory.eINSTANCE.createV2VPlatoonOutput();
		input.setName("V2V Platoon Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VLeaderHeartbeatInput} */
	public static V2VLeaderHeartbeatInput createV2vLeaderHeartbeatInput() {
		V2VLeaderHeartbeatInput input = V2vFactory.eINSTANCE.createV2VLeaderHeartbeatInput();
		input.setName("V2V Leader Heartbeat Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VLeaderHeartbeatOutput} */
	public static V2VLeaderHeartbeatOutput createV2vLeaderHeartbeatOutput() {
		V2VLeaderHeartbeatOutput input = V2vFactory.eINSTANCE.createV2VLeaderHeartbeatOutput();
		input.setName("V2V Leader Heartbeat Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFollowerInput} */
	public static V2VFollowerInput createV2vFollowerInput() {
		V2VFollowerInput input = V2vFactory.eINSTANCE.createV2VFollowerInput();
		input.setName("V2V Follower Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFollowerOutput} */
	public static V2VFollowerOutput createV2vFollowerOutput() {
		V2VFollowerOutput input = V2vFactory.eINSTANCE.createV2VFollowerOutput();
		input.setName("V2V Follower Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VLeavePlatoonInput}. */
	public static V2VLeavePlatoonInput createV2vLeavePlatoonInput() {
		V2VLeavePlatoonInput input = V2vFactory.eINSTANCE.createV2VLeavePlatoonInput();
		input.setName("Leave Platoon Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VLeavePlatoonOutput}. */
	public static V2VLeavePlatoonOutput createV2vLeavePlatoonOutput() {
		V2VLeavePlatoonOutput input = V2vFactory.eINSTANCE.createV2VLeavePlatoonOutput();
		input.setName("Leave Platoon Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VSplitInput} */
	public static V2VSplitInput createV2vSplitInput() {
		V2VSplitInput input = V2vFactory.eINSTANCE.createV2VSplitInput();
		input.setName("V2V Split Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VSplitOutput} */
	public static V2VSplitOutput createV2vSplitOutput() {
		V2VSplitOutput input = V2vFactory.eINSTANCE.createV2VSplitOutput();
		input.setName("V2V Split Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VNewLeaderInput}. */
	public static V2VNewLeaderInput createV2vNewLeaderInput() {
		V2VNewLeaderInput input = V2vFactory.eINSTANCE.createV2VNewLeaderInput();
		input.setName("V2V New Leader Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VNewLeaderOutput}. */
	public static V2VNewLeaderOutput createV2vNewLeaderOutput() {
		V2VNewLeaderOutput input = V2vFactory.eINSTANCE.createV2VNewLeaderOutput();
		input.setName("V2V New Leader Output");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFusePlatoonInput}. */
	public static V2VFusePlatoonInput createV2vFusePlatoonInput() {
		V2VFusePlatoonInput input = V2vFactory.eINSTANCE.createV2VFusePlatoonInput();
		input.setName("V2V Fuse Platoon Input");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFusePlatoonInput}. */
	public static V2VFusePlatoonOutput createV2VFusePlatoonOutput() {
		V2VFusePlatoonOutput input = V2vFactory.eINSTANCE.createV2VFusePlatoonOutput();
		input.setName("V2V Fuse Platoon Ouput");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VHandshakeInput}. */
	public static V2VHandshakeInput createV2VHandshakeInput() {
		V2VHandshakeInput input = V2vFactory.eINSTANCE.createV2VHandshakeInput();
		input.setName("V2VHandshakeInput");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VHandshakeOutput}. */
	public static V2VHandshakeOutput createV2VHandshakeOutput() {
		V2VHandshakeOutput input = V2vFactory.eINSTANCE.createV2VHandshakeOutput();
		input.setName("V2VHandshakeOutput");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFusePlatoonOutput}. */
	public static V2VPrecedingUIDOuput createV2VPrecedingUIDOuput() {
		V2VPrecedingUIDOuput input = V2vFactory.eINSTANCE.createV2VPrecedingUIDOuput();
		input.setName("V2VPrecedingUIDOuput");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFusePlatoonOutput}. */
	public static V2VLocalUIDOutput createV2VLocalUIDOutput() {
		V2VLocalUIDOutput input = V2vFactory.eINSTANCE.createV2VLocalUIDOutput();
		input.setName("V2VLocalUIDOutput");
		createConnectorLayout(input);
		return input;
	}

	/** Creates a {@link V2VFusePlatoonOutput}. */
	public static V2VLeaderUIDOutput createV2VLeaderUIDOutput() {
		V2VLeaderUIDOutput input = V2vFactory.eINSTANCE.createV2VLeaderUIDOutput();
		input.setName("V2VLeaderUIDOutput");
		createConnectorLayout(input);
		return input;
	}
}
